mypredict.lm: Predictions Based on Linear Models
Description
Function to predict a vector of full length (number of observations), where predictions according to missing
explanatory values are replaced by NA.
Usage
mypredict.lm(object, newdata)
Arguments
newdata
matrix or data frame to be predicted according to object.
Value
Vector of predicted values.